summaryrefslogtreecommitdiffstats
path: root/part/kxe_treeviewitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'part/kxe_treeviewitem.h')
-rw-r--r--part/kxe_treeviewitem.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/part/kxe_treeviewitem.h b/part/kxe_treeviewitem.h
index c24b99f..20430f8 100644
--- a/part/kxe_treeviewitem.h
+++ b/part/kxe_treeviewitem.h
@@ -18,24 +18,24 @@
#ifndef KXE_TREEVIEWITEM_H
#define KXE_TREEVIEWITEM_H
-#include <qlistview.h>
-#include <qpixmap.h>
-#include <qdom.h>
+#include <tqlistview.h>
+#include <tqpixmap.h>
+#include <tqdom.h>
class KListView;
/**
* This is a tree item, which represents one XML node (see @ref QDomNode and its childclasses).
* @short tree item
* @author The KXMLEditor Team
*/
-class KXE_TreeViewItem : public QListViewItem
+class KXE_TreeViewItem : public TQListViewItem
{
public:
- KXE_TreeViewItem( const QDomNode & xmlNode, KListView * pParent, QListViewItem* pAfter=NULL);
- KXE_TreeViewItem( const QDomNode & xmlNode, QListViewItem * pParent );
- KXE_TreeViewItem( const QDomNode & xmlNode, QListViewItem * pParent, QListViewItem * pAfter );
+ KXE_TreeViewItem( const TQDomNode & xmlNode, KListView * pParent, TQListViewItem* pAfter=NULL);
+ KXE_TreeViewItem( const TQDomNode & xmlNode, TQListViewItem * pParent );
+ KXE_TreeViewItem( const TQDomNode & xmlNode, TQListViewItem * pParent, TQListViewItem * pAfter );
~KXE_TreeViewItem();
/**
@@ -47,7 +47,7 @@ class KXE_TreeViewItem : public QListViewItem
void setTexts();
/** Returns the corresponding XML node, e.g. the XML node represented by this tree item. */
- QDomNode * xmlNode() { return & m_xmlNode; }
+ TQDomNode * xmlNode() { return & m_xmlNode; }
/** Returns true, if this tree item is bookmarked (false otherwise). */
bool isBookmarked() const { return m_bBookmarked; }
@@ -65,7 +65,7 @@ class KXE_TreeViewItem : public QListViewItem
KXE_TreeViewItem * prevSibling() const { return m_pPrevSibling; }
/**
* Does the same like @ref QListViewItem::itemAbove but the parent items doesn't need to be open.
* Returns this items previous siblings last grand child, if there is one.
* Otherwise it returns this items previous sibling or,
* if there are no sibling above, it returns this items parent or
@@ -74,7 +74,7 @@ class KXE_TreeViewItem : public QListViewItem
KXE_TreeViewItem * prevItem();
/**
* Does the same like @ref QListViewItem::itemBelow but the parent items doesn't need to be open.
* Returns a pointer to the next item of this or a null pointer if this is the last item.
* This will be it's first child,
* if there are no childs, it will be the next sibling
@@ -110,7 +110,7 @@ class KXE_TreeViewItem : public QListViewItem
protected:
- QDomNode m_xmlNode;
+ TQDomNode m_xmlNode;
KXE_TreeViewItem * m_pPrevSibling;
bool m_bBookmarked;
bool m_bChildsCreated;
@@ -18,24 +18,24 @@
class KListView;
/**
- * This is a tree item, which represents one XML node (see @ref QDomNode and its childclasses).
+ * This is a tree item, which represents one XML node (see @ref TQDomNode and its childclasses).
* @short tree item
* @author The KXMLEditor Team
@@ -65,7 +65,7 @@ class KXE_TreeViewItem : public QListViewItem
KXE_TreeViewItem * prevSibling() const { return m_pPrevSibling; }
/**
- * Does the same like @ref QListViewItem::itemAbove but the parent items doesn't need to be open.
+ * Does the same like @ref TQListViewItem::itemAbove but the parent items doesn't need to be open.
* Returns this items previous siblings last grand child, if there is one.
* Otherwise it returns this items previous sibling or,
@@ -74,7 +74,7 @@ class KXE_TreeViewItem : public QListViewItem
KXE_TreeViewItem * prevItem();
/**
- * Does the same like @ref QListViewItem::itemBelow but the parent items doesn't need to be open.
+ * Does the same like @ref TQListViewItem::itemBelow but the parent items doesn't need to be open.
* Returns a pointer to the next item of this or a null pointer if this is the last item.
* This will be it's first child,